Gemeinde Adressverwaltung GUI: Gemeinde.dialogLogin Klassenreferenz

Gemeinde Adressverwaltung GUI

Öffentliche Methoden | Öffentliche Attribute | Aufstellung aller Elemente
Gemeinde.dialogLogin Klassenreferenz
Klassendiagramm für Gemeinde.dialogLogin:
[Legende]
Zusammengehörigkeiten von Gemeinde.dialogLogin:
[Legende]

## Öffentliche Methoden
def | __init__ (self, parent)
def | setLoginDaten (self)

## Öffentliche Attribute
| parent
| lblTitel
| lblErfolg
| lblBenutzer
| lblPassword
| user
| entBenutzer
| password
| entPassword
| btnQuit
| btnLogin

Die Dokumentation für diese Klasse wurde erzeugt aufgrund der Datei:

- Gemeinde.py